Name:           gerbera
Version:        2.1.0
Release:        %mkrel 1
Summary:        UPnP Media Server
License:        GPLv2 and MIT and OFL
Group:          System/Servers
Url:            https://gerbera.io
Source0:        https://github.com/gerbera/gerbera/archive/v%{version}/%{name}-%{version}.tar.gz
Source2:        gerbera.sysconfig
Patch1:         gerbera-sysconfig.patch

BuildRequires:	cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  curl-devel
BuildRequires:  duktape-devel
BuildRequires:  exiv2-devel
BuildRequires:  expat-devel
BuildRequires:  ffmpeg-devel
BuildRequires:  file-devel
BuildRequires:  fmt-devel
BuildRequires:  libebml-devel
BuildRequires:  libexif-devel
BuildRequires:  libffmpegthumbnailer-devel
BuildRequires:  libmatroska-devel
BuildRequires:  libupnp-devel
BuildRequires:  libuuid-devel
BuildRequires:  pugixml-devel
BuildRequires:  spdlog-devel
BuildRequires:  sqlite3-devel
BuildRequires:  systemd-devel
BuildRequires:  taglib-devel
BuildRequires:  zlib-devel

%{?systemd_requires}
Requires:       %{name}-data = %{version}-%{release}
Obsoletes:      mediatomb < 0.12.1-26

%description
Gerbera is a UPnP media server which allows you to stream your digital
media through your home network and consume it on a variety of UPnP
compatible devices.

%package data
Summary:        Data files for Gerbera
BuildArch:      noarch

%description data
Data files for the Gerbera media server.

%prep
%autosetup -n %{name}-%{version} -p1

# use Release as default serial number in device description
sed -i -e '/DESC_SERIAL_NUMBER/s/".*"/"%{release}"/' src/config/config_definition.cc

%build
%cmake \
    -DWITH_JS:BOOL=YES \
    -DWITH_MYSQL:BOOL=NO \
    -DWITH_CURL:BOOL=YES \
    -DWITH_TAGLIB:BOOL=YES \
    -DWITH_MAGIC:BOOL=YES \
    -DWITH_AVCODEC:BOOL=YES \
    -DWITH_EXIF:BOOL=YES \
    -DWITH_EXIV2:BOOL=YES \
    -DWITH_FFMPEGTHUMBNAILER:BOOL=YES \
    -DWITH_INOTIFY:BOOL=YES \
    -DWITH_SYSTEMD:BOOL=YES \
    -DUPNP_HAS_REUSEADDR:BOOL=YES
%cmake_build

%install
%cmake_install

# default config
mkdir -p %{buildroot}%{_sysconfdir}/gerbera/
%{_vpath_builddir}/gerbera --create-config > %{buildroot}%{_sysconfdir}/gerbera/config.xml
sed -i -e 's!\(<home>\).*\(</home>\)!\1%{_sysconfdir}/gerbera\2!' %{buildroot}%{_sysconfdir}/gerbera/config.xml

# sysconfig
install -p -D -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

# make all files under %%_sysconfdir/gerbera owned by
# this package
mkdir -p %{buildroot}%{_sysconfdir}/gerbera
touch %{buildroot}%{_sysconfdir}/gerbera/{gerbera.db,gerbera.html}

%pre
%_pre_useradd %{name} %{_sysconfdir}/gerbera %{_sbindir}/nologin

%post
%systemd_post gerbera.service

%preun
%systemd_preun gerbera.service

%postun
%systemd_postun_with_restart gerbera.service

%files
%license LICENSE.md
%doc AUTHORS CONTRIBUTING.md ChangeLog.md
%attr(-,gerbera,gerbera) %dir %{_sysconfdir}/%{name}/
%attr(-,gerbera,gerbera) %config(noreplace) %{_sysconfdir}/%{name}/*
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_bindir}/%{name}
%{_mandir}/man1/*
%{_unitdir}/gerbera.service

%files data
%dir %{_datadir}/gerbera/
%{_datadir}/gerbera/mysql.sql
%{_datadir}/gerbera/mysql-upgrade.xml
%{_datadir}/gerbera/sqlite3.sql
%{_datadir}/gerbera/sqlite3-upgrade.xml
%{_datadir}/gerbera/js/
%{_datadir}/gerbera/web/


%changelog
* Wed May 08 2024 wally <wally> 2.1.0-1.mga10
+ Revision: 2062894
- new version 2.1.0
- rebuild for spdlog 1.14.1

* Sat Feb 10 2024 daviddavid <daviddavid> 1.12.1-4.mga10
+ Revision: 2040064
- rebuild for new spdlog

* Mon Oct 02 2023 daviddavid <daviddavid> 1.12.1-3.mga10
+ Revision: 1993114
- rebuild for new exiv2 0.28.0

* Wed Sep 06 2023 papoteur <papoteur> 1.12.1-2.mga10
+ Revision: 1984854
- rebuid for spdlog 1.12

* Fri Jan 06 2023 wally <wally> 1.12.1-1.mga9
+ Revision: 1930734
- new version 1.12.1

* Sat Dec 17 2022 wally <wally> 1.12.0-2.mga9
+ Revision: 1924420
- rebuild for duktape 2.7.0

* Sun Dec 04 2022 wally <wally> 1.12.0-1.mga9
+ Revision: 1917619
- new version 1.12.0

* Fri Nov 04 2022 papoteur <papoteur> 1.11.0-4.mga9
+ Revision: 1902532
- rebuild for libspdlog

* Thu Oct 13 2022 neoclust <neoclust> 1.11.0-3.mga9
+ Revision: 1896762
- Fix build against new fmt
+ papoteur <papoteur>
- Rebuild for fmt 9

* Mon May 09 2022 wally <wally> 1.11.0-1.mga9
+ Revision: 1857180
- new version 1.11.0

* Sat Apr 23 2022 wally <wally> 1.10.0-1.mga9
+ Revision: 1852826
- new version 1.10.0

* Sat Mar 12 2022 mrambo3501 <mrambo3501> 1.9.2-2.mga9
+ Revision: 1790671
- rebuild for ffmpeg 5.0

* Sat Oct 09 2021 wally <wally> 1.9.2-1.mga9
+ Revision: 1750173
- new version 1.9.2

* Wed Sep 01 2021 wally <wally> 1.9.1-1.mga9
+ Revision: 1743984
- new version 1.9.1

* Wed Aug 04 2021 wally <wally> 1.9.0-1.mga9
+ Revision: 1739289
- new version 1.9.0
- use release as default serial number in web interface device description

* Sun Jul 11 2021 wally <wally> 1.8.2-3.mga9
+ Revision: 1735661
- update systemd service to support configuration via /etc/sysconfig/gerbera (mga#29230)
- log to systemd journal by default
- create default configuration while building

* Thu Jun 24 2021 wally <wally> 1.8.2-2.mga9
+ Revision: 1732135
- rebuild for fmt 8.0.0

* Tue Jun 22 2021 wally <wally> 1.8.2-1.mga9
+ Revision: 1731708
- new version 1.8.2
- update config.xml

* Fri Dec 04 2020 luigiwalser <luigiwalser> 1.6.4-3.mga8
+ Revision: 1652440
- rebuild for libupnp

* Tue Nov 17 2020 wally <wally> 1.6.4-2.mga8
+ Revision: 1646910
- rebuild for new duktape 2.6.0

* Sat Oct 17 2020 wally <wally> 1.6.4-1.mga8
+ Revision: 1636529
- new version 1.6.4

* Thu Oct 15 2020 wally <wally> 1.6.1-2.mga8
+ Revision: 1636270
- fix user creation in %%pre (mga#27425)
- build with avcodec

* Mon Oct 12 2020 wally <wally> 1.6.1-1.mga8
+ Revision: 1634581
- new version 1.6.1

* Sat Aug 22 2020 wally <wally> 1.6.0-1.mga8
+ Revision: 1617977
- new version 1.6.0

* Wed Jul 22 2020 zezinho <zezinho> 1.5.0-2.mga8
+ Revision: 1607849
- rebuild against new libebml5

* Sun May 24 2020 wally <wally> 1.5.0-1.mga8
+ Revision: 1587304
- import based on .spec from Fedora
- obsolete mediatomb

